@@ -20,7 +20,7 @@ from sqlalchemy import create_engine
 
 from tropofy.database import read_write_xl
 from data_set import AppDataSet
-from tropofy.widgets import DataSets
+from tropofy.widgets import DataSets, ExecuteFunction
 from tropofy.database import DBSession
 from tropofy.database.tropofy_orm import ORMBase, TropofyDbMetaData
 
@@ -35,7 +35,7 @@ class App(object):
         App.global_app_indexer += 1
         self.name = self.get_name()
         self.url_name = make_safe_url_name(self.name)
-        self.schema_name = self.get_schema_name() if hasattr(self, 'get_schema_name') else ''
+        self.schema_name = None
         self.developer_id = None
         self.step_groups = []
         self.app_folder_path = os.path.split(os.path.realpath(inspect.getfile(type(self))))[0]
@@ -132,7 +132,7 @@ class App(object):
 
         mapping = {}
         for class_ in orm_classes:
-            table_name = self.schema_name + "." + class_.__tablename__ if self.schema_name else class_.__tablename__
+            table_name = class_.__tablename__ if self.schema_name else class_.__tablename__
             tables = TropofyDbMetaData.get_dependency_sorted_tables([table_name])
             if tables:
                 mapping[tables[0]] = class_
@@ -204,7 +204,9 @@ class AppWithDataSets(App):
             data_set.name = example_data_set_name if example_data_set_name else "Empty"
         DBSession().add(data_set)
         DBSession().flush()
+
         data_set.init_parameters_with_defaults()  # Must be done here and not in AppDataSet.__init__ as requires data set to have ID.
+
         if example_data_set_name and self.get_examples():
             try:
                 populate_example = self.get_examples().get(example_data_set_name)
@@ -213,6 +215,10 @@ class AppWithDataSets(App):
             except Exception:
                 print(traceback.format_exc())
                 print("WARNING: An error occured loading your example data set. See Traceback above.")
+
+        for execute_function_widget in [w for w in self.get_all_widgets() if w.get_type() == ExecuteFunction.TYPE]:
+            data_set.init_function_execution_info(execute_function_widget)
+
         return data_set
 
     def get_name(self):
