@@ -24,11 +24,13 @@ from sqlalchemy.schema import Column, UniqueConstraint
 from sqlalchemy.orm import relationship
 from sqlalchemy import event
 from sqlalchemy.orm.exc import NoResultFound
+from sqlalchemy.ext.declarative import declared_attr
 from sqlalchemy.exc import OperationalError
 from tropofy.views import post_to_gui_server
 from tropofy.database.tropofy_orm import ORMBase, DataSetMixin, ExtendedJsonEncoder, Validator, ValidationException
 from tropofy.database import DBSession
 from tropofy.app import LoadedApps
+from tropofy.database.tropofy_orm import DynamicSchemaName
 
 
 class DataSetDBInterface(object):
@@ -82,6 +84,10 @@ class AppDataSet(ORMBase):
     latest_enabled_step_index = Column(Integer, nullable=False)
     execute_functions_info = Column(Text)
     saved_image_references = relationship('SavedImageReference')
+    
+    __table_args__ = (
+        {"schema": DynamicSchemaName.COMPUTE_NODE_SCHEMA_NAME} if DynamicSchemaName.use_app_schemas else {},
+    )
 
     def __init__(self, app, user_email, name=''):
         self.app_name = app.name
@@ -107,15 +113,13 @@ class AppDataSet(ORMBase):
         except:
             pass
 
+    def init_function_execution_info(self, execute_function_widget):
+        self.add(FunctionExecutionInfo(execute_function_widget.id))
+
     @property
     def execute_function_info(self):
         widget_id = threadlocal.get_current_request().widget.id
-        try:
-            return self.query(FunctionExecutionInfo).filter_by(widget_id=widget_id).one()
-        except NoResultFound:  # MultipleResultsFound would be an error. NoResultFound is expected on first function execution. 
-            fn_execution_info = FunctionExecutionInfo(widget_id)
-            self.add(fn_execution_info)
-            return fn_execution_info
+        return self.query(FunctionExecutionInfo).filter_by(widget_id=widget_id).one()
 
     @property
     def created_datetime_str(self):
@@ -296,7 +300,10 @@ class DataSetVar(DataSetMixin):
     value_as_json_str = Column(Text, nullable=True)
     stored_type = Column(Text)  # Stores the type of object that got stored, so that it can be decoded back out. 
 
-    __table_args__ = (UniqueConstraint('name', 'data_set_id'),)
+    __table_args__ = (
+        UniqueConstraint('name', 'data_set_id'),
+        {"schema": DynamicSchemaName.COMPUTE_NODE_SCHEMA_NAME} if DynamicSchemaName.use_app_schemas else {}
+    )
 
     def __init__(self, name, value=None, type=None):
         self.name = name
@@ -324,7 +331,10 @@ class FunctionExecutionInfo(DataSetMixin):
     num_times_run = Column(Integer, nullable=False, default=0)
     last_run_start_time = Column(DateTime)
 
-    __table_args__ = (UniqueConstraint('widget_id', 'data_set_id'),)
+    __table_args__ = (
+        UniqueConstraint('widget_id', 'data_set_id'),
+        {"schema": DynamicSchemaName.COMPUTE_NODE_SCHEMA_NAME} if DynamicSchemaName.use_app_schemas else {}
+    )
 
     def __init__(self, widget_id):
         self.widget_id = widget_id
@@ -364,7 +374,10 @@ class SavedImageReference(DataSetMixin):
     datetime_saved = Column(DateTime)
     data_set = relationship('AppDataSet')
 
-    __table_args__ = (UniqueConstraint('image_name', 'data_set_id'),)
+    __table_args__ = (
+        UniqueConstraint('image_name', 'data_set_id'),
+        {"schema": DynamicSchemaName.COMPUTE_NODE_SCHEMA_NAME} if DynamicSchemaName.use_app_schemas else {}
+    )
 
     def __init__(self, image_name):
         self.image_name = image_name
