@@ -22,6 +22,7 @@ import datetime
 import xlrd
 import transaction
 from operator import attrgetter
+import collections
 
 
 # http://pythonhosted.org/openpyxl/usage.html
@@ -120,7 +121,7 @@ class ClassWsMapping(object):
                         class_ = None
 
                 required_attribute_names = [col.name for col in table.columns if col.name not in ['id', 'data_set_id']]
-                attribute_column_aliases = {}
+                attribute_column_aliases = collections.OrderedDict()  # I want the column ordering in the excel file to be the same as that in the grids
                 for name in required_attribute_names:
                     attribute_column_aliases.update({name: name})
 
