@@ -24,7 +24,7 @@ class CustomExport(Widget):
     def get_type(self):
         return "CustomExportWidget"
 
-    def refresh_from_db(self, data_set):
+    def refresh_from_db(self, data_set, request):
         if data_set:
             return {'get_custom_export_data': self.get_custom_export_data(data_set)}
 
