@@ -330,6 +330,13 @@ class Filter(Form):
         return 'filter.%s' % self.id
 
     def get_values(self, data_set):
+        """Values of filter, indexed by form element name.
+
+        It is possible to overide this method and return custom, computed values. For example, if the form has separate input date, and time fields, these could be combined for a datetime value.
+        If doing this, it is requiered that all form values be returned also, and not replaced. This is necessary to ensure the form updates on reload appropriately.
+
+        :returns: dict
+        """
         values = {}
         for element in self.get_form_elements(data_set):  # Would be a way to make this faster by storing just the names somewhere other than get_form_elements. Would probably need an extra use fn though.
             value = data_set.get_var(self._get_var_name(element.name))  # Don't return a None value, just don't return the key!
