@@ -19,7 +19,6 @@ or FITNESS FOR A PARTICULAR PURPOSE. See the license files for details.
 '''
 
 import os
-from gurobipy import GRB, Model, quicksum, tuplelist
 from sqlalchemy.types import Integer, Text, Float
 from sqlalchemy.schema import Column, ForeignKeyConstraint, UniqueConstraint
 from sqlalchemy.orm import relationship, backref
@@ -44,7 +43,9 @@ class TravellingSalesManStop(DataSetMixin):
         self.longitude = longitude
         self.ordinal = ordinal
 
-    __table_args__ = (UniqueConstraint('data_set_id', 'name'),)
+    @classmethod
+    def get_table_args(cls):
+        return (UniqueConstraint('data_set_id', 'name'),)
 
 
 class KMLMapForStops(KMLMap):
@@ -192,7 +193,7 @@ def formulate_and_solve_travelling_salesman_problem(data_set):
 
     # Callback - use lazy constraints to eliminate sub-tours
     def subtourelim(model, where):
-        if where == GRB.callback.MIPSOL:
+        if where == gurobipy.GRB.callback.MIPSOL:
             selected = []
             # make a list of edges selected in the solution
             for i in range(n):
@@ -239,19 +240,19 @@ def formulate_and_solve_travelling_salesman_problem(data_set):
     points = data_set.query(TravellingSalesManStop).all()
     n = len(points)
 
-    m = Model()
+    m = gurobipy.Model()
 
     # Create variables
     variables = {}
     for i in range(n):
         for j in range(i + 1):
-            variables[i, j] = m.addVar(obj=distance(points, i, j), vtype=GRB.BINARY, name='e' + str(i) + '_' + str(j))
+            variables[i, j] = m.addVar(obj=distance(points, i, j), vtype=gurobipy.GRB.BINARY, name='e' + str(i) + '_' + str(j))
             variables[j, i] = variables[i, j]
     m.update()
 
     # Add degree-2 constraint, and forbid loops
     for i in range(n):
-        m.addConstr(quicksum(variables[i, j] for j in range(n)) == 2)
+        m.addConstr(gurobipy.quicksum(variables[i, j] for j in range(n)) == 2)
         variables[i, i].ub = 0
     m.update()
 
